#!/bin/sh

####################################################################
# Licensed Materials - Property of IBM
# "Restricted Materials of IBM"
# 5724-N93
# (C) Copyright IBM Corp. 2007 All Rights Reserved.
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
###################################################################

#initialize variables
INSTALLSRC=""; export INSTALLSRC
ERROR="0"; export ERROR
TDWBDIR=""; export TDWBDIR
WASUSER=""; export WASUSER
WASPASSWORD=""; export WASPASSWORD
WASPROFILEPATH=""; export WASPROFILEPATH
OPTIONAL=""; export OPTIONAL


###### MODIFY THIS IF YOUR WAS USES A LONG INSTALLATION PATH ######
TEMPDIR=

###### MODIFY THIS IF YOUR MASTER TAG DOES NOT CONTAIN A VALID WAS PROFILE PATH ######
WASPROFILEPATH=

#The range for return codes for this script is: [21 - 49].
#The reason is explained below for each return code.
#0   - successful
#21   - bad usage
#22   - invalid command line parameters
#23   - TDWB install location doesn't exist
#24   - WAS Profile Path doesn't exist
#26   - error updating WAR module



#This method is used for abnormal termination. The following parameters must be passed
#   reason      -   failure explanation
#   exit code
exitOnError()
{
	exitCode=$1
	shift
	reason=$*
        echo "ERROR: The script ended abnormally. The reason is: $reason"
	echo "The script exit code is $exitCode"
	exit $exitCode
}

#This method is used when the usage option is used. The following parameter must be passed
#   exit code
exitOnUsage()
{
	exitCode=$1
# echo "The script exit code is $exitCode"
	exit $exitCode
}



#MAIN

#Parsing Parameters

while [ $# -gt 0 ]
do
  	CPARM=$1; export CPARM
  	shift

  	case $CPARM in


  	  -user)
  	    if [ -z "$WASUSER" ]
  	    then
  	      	if [ $# -eq 0 ] || [ "`echo $1 | cut -c1`" = "-" ]
  	      	then
  	      	  	echo " An incorrect value has been supplied for the user parameter"
  	      	  	echo " Use the -usage option to see the available command line options"
  	      	  	ERROR="22"
  	      	  	reason="incorrect value for parameter user."
  	      	  	exitOnError $ERROR $reason
  	      	else 
  	      		WASUSER=$1; export WASUSER
  	      		shift
  	      	fi
  	    else
  	     	ERROR="22"
  	     	reason="command option -user supplied more than once."
  	     	exitOnError $ERROR $reason
  	    fi
  	  ;;

  	  -password)
  	    if [ -z "$WASPASSWORD" ]
  	    then
  	      	if [ $# -eq 0 ] || [ "`echo $1 | cut -c1`" = "-" ]
  	      	then
  	      	  	echo " An incorrect value has been supplied for the password parameter"
  	      	  	echo " Use the -usage option to see the available command line options"
  	      	  	ERROR="22"
  	      	  	reason="incorrect value for parameter password."
  	      	  	exitOnError $ERROR $reason
  	      	else
  	      		WASPASSWORD=$1; export WASPASSWORD
  	      		shift
  	      	fi
  	    else
  	     	ERROR="22"
  	     	reason="command option -password supplied more than once."
  	     	exitOnError $ERROR $reason
  	    fi
  	  ;;
  	  -usage)
      	echo " The usage of the install.sh is :"
      	echo " install.sh [-user wasUser -password wasUserPassword]"
        echo "    wasUser          - Was Administrator"
        echo "    wasUserPassword  - Was Administrator Password"
  	    ERROR="0"
  	    reason="The usage option was used in order to show the script usage."
  	    exitOnUsage $ERROR
  	  ;;

  	  -help)
      	echo " The usage of the install.sh is :"
      	echo " install.sh [-user wasUser -password wasUserPassword]"
        echo "    wasUser          - Was Administrator"
        echo "    wasUserPassword  - Was Administrator Password"
  	    ERROR="0"
  	    reason="The usage option was used in order to show the script usage."
  	    exitOnUsage $ERROR
  	  ;;


  	  *)
  	    echo " The command line is invalid"
  	    echo " Use the -usage or -help option to see the available command line options"
  	    ERROR="22"
  	    reason="invalid command line."
  	    exitOnError $ERROR $reason
  	  ;;

  	esac

done


INSTALLSRC=`pwd`
TDWBDIR=$INSTALLSRC/..
BRIDGE_APPLICATION=TWSAgent
BRIDGE_EAR_FILE=$INSTALLSRC/TWSAgentEAR.ear
MASTERTAG=$TDWBDIR/Install/master.tag


if [ ! -z "$WASUSER" ]&[ ! -z "$WASPASSWORD" ]
   then OPTIONAL=" -user $WASUSER -password $WASPASSWORD "; export OPTIONAL
fi

if [ ! -z "$TEMPDIR" ]
   then TEMPDIR="-javaoption -Dworkspace.user.root=$TEMPDIR"; export TEMPDIR
fi


# check the TDWBDIR dir
if [ ! -f "$MASTERTAG" ]
then
    echo " The $TDWBDIR does not seem to be a valid TDWB install location."
    echo " Please check the existence of the file $MASTERTAG"
    ERROR="23"
    reason="wrong install location path."
    exitOnError $ERROR $reason
fi

if [ -z "$WASPROFILEPATH" ]
then
   WASPROFILEPATH=`cat $MASTERTAG | grep TDWB_WAS_PROFILE_PATH | cut -f 2 -d =`; export WASPROFILEPATH
fi

# check the WASPROFILEPATH dir
if [ ! -d "$WASPROFILEPATH" ]
then
    echo " The master tag in the TDWB install location, ($TDWBDIR/Install/master.tag), does not contain a valid WAS Profile Path."
    echo " Please specify the proper location for the WAS Profile Path installation."
    ERROR="24"
    reason="unexisting was profile path."
    exitOnError $ERROR $reason
fi

# setting the enviroment from TWAAgentConfig
cat $TDWBDIR/config/TWSAgentConfig.properties | grep TWSAgent.retrylink > /dev/null
if [ $? -ne 0 ]
then
    cp $TDWBDIR/config/TWSAgentConfig.properties $TDWBDIR/config/TWSAgentConfig.properties.orig > /dev/null
    echo "                                     " >> $TDWBDIR/config/TWSAgentConfig.properties
    echo "# TWS Agent Retry link Configuration " >> $TDWBDIR/config/TWSAgentConfig.properties
    echo "#----------------------------------- " >> $TDWBDIR/config/TWSAgentConfig.properties
    echo "TWSAgent.retrylink=600               " >> $TDWBDIR/config/TWSAgentConfig.properties
    echo "                                     " >> $TDWBDIR/config/TWSAgentConfig.properties
fi


echo
echo Updating the $BRIDGE_APPLICATION application ...
echo
# RUN WSADMIN
$WASPROFILEPATH/bin/wsadmin.sh $OPTIONAL -lang jython -javaoption "-Dpython.path=$INSTALLSRC" $TEMPDIR -f "$INSTALLSRC/updateEAR.py" -application "$BRIDGE_APPLICATION" -application_ear "$BRIDGE_EAR_FILE"
if [ $? -ne 0 ]
   then
    	ERROR="26"
    	reason="possible error, $ERROR, creating profile $PROFILENAME, $WASPROFILEPATH/logs/wsadmin.traceout."
    	exitOnError $ERROR $reason
fi

echo " The update of $BRIDGE_APPLICATION application is complete"
echo "Exited successfully"
exit 0

